from .letter_frequency_by_language import letter_frequency_by_language
from .bigram_frequency_by_language import bigram_frequency_by_language
from .index_of_coincidence_by_language import index_of_coincidence_by_language
from .frequent_short_words_by_language import frequent_short_words_by_language
from .trigram_frequency_by_language import trigram_frequency_by_language
