frequent_short_words_by_language = {
    "en": {
        1: ["a", "i"],
        2: ["am", "an", "as", "at", "be", "by", "do", "go", "he", "if", "in", "is", "it", "me", "mr", "my", "no", "of",
            "oh", "ok", "on", "or", "PM", "so", "to", "tv", "up", "us", "we"],
        3: ["act", "add", "age", "ago", "air", "all", "and", "any", "are", "arm", "art", "ask", "bad", "bag", "bar",
            "bed", "big", "bit", "box", "boy", "but", "buy", "can", "car", "cup", "cut", "day", "die", "dog", "eat",
            "end", "eye", "far", "few", "fly", "for", "gas", "get", "gun", "guy", "has", "her", "him", "his", "hit",
            "hot", "how", "its", "job", "key", "kid", "law", "lay", "leg", "let", "lie", "lot", "low", "man", "may",
            "mrs", "new", "nor", "not", "now", "n't", "off", "oil", "old", "one", "our", "out", "own", "pay", "per",
            "put", "red", "run", "say", "sea", "see", "set", "sex", "she", "sit", "six", "son", "tax", "ten", "the",
            "too", "top", "try", "two", "use", "war", "was", "way", "who", "why", "win", "yes", "yet", "you"],
        4: ["able", "also", "area", "away", "baby", "back", "ball", "bank", "base", "beat", "best", "bill", "blue",
            "body", "book", "born", "both", "call", "card", "care", "case", "cell", "city", "cold", "come", "cost",
            "dark", "data", "dead", "deal", "deep", "door", "down", "draw", "drop", "drug", "each", "east", "easy",
            "edge", "else", "even", "ever", "face", "fact", "fail", "fall", "fast", "fear", "feel", "fill", "film",
            "find", "fine", "fire", "firm", "fish", "five", "food", "foot", "form", "four", "free", "from", "full",
            "fund", "game", "girl", "give", "goal", "good", "grow", "hair", "half", "hand", "hang", "hard", "have",
            "head", "hear", "heat", "help", "here", "high", "hold", "home", "hope", "hour", "huge", "idea", "into",
            "item", "join", "just", "keep", "kill", "kind", "know", "land", "last", "late", "lead", "left", "less",
            "life", "like", "line", "list", "live", "long", "look", "lose", "loss", "love", "main", "make", "many",
            "mean", "meet", "mind", "miss", "more", "most", "move", "much", "must", "name", "near", "need", "news",
            "next", "nice", "none", "note", "once", "only", "onto", "open", "over", "page", "pain", "part", "pass",
            "past", "pick", "plan", "play", "poor", "pull", "push", "race", "rate", "read", "real", "rest", "rich",
            "rise", "risk", "road", "rock", "role", "room", "rule", "safe", "same", "save", "seat", "seek", "seem",
            "sell", "send", "shot", "show", "side", "sign", "sing", "site", "size", "skin", "some", "song", "soon",
            "sort", "star", "stay", "step", "stop", "such", "sure", "take", "talk", "task", "team", "tell", "tend",
            "term", "test", "than", "that", "them", "then", "they", "this", "thus", "time", "town", "tree", "trip",
            "true", "turn", "type", "unit", "upon", "very", "view", "vote", "wait", "walk", "wall", "want", "wear",
            "week", "well", "west", "what", "when", "whom", "wide", "wife", "will", "wind", "wish", "with", "word",
            "work", "yard", "yeah", "year", "your"],
        5: ["about", "above", "admit", "adult", "after", "again", "agent", "agree", "ahead", "allow", "alone", "along",
            "among", "apply", "argue", "avoid", "begin", "black", "blood", "board", "break", "bring", "build", "carry",
            "catch", "cause", "chair", "check", "child", "civil", "claim", "class", "clear", "close", "coach", "color",
            "could", "court", "cover", "crime", "death", "dream", "drive", "early", "eight", "enjoy", "enter", "event",
            "every", "exist", "field", "fight", "final", "first", "floor", "focus", "force", "front", "glass", "great",
            "green", "group", "guess", "happy", "heart", "heavy", "hotel", "house", "human", "image", "issue", "large",
            "later", "laugh", "learn", "least", "leave", "legal", "level", "light", "local", "major", "maybe", "media",
            "might", "model", "money", "month", "mouth", "movie", "music", "never", "night", "north", "occur", "offer",
            "often", "order", "other", "owner", "paper", "party", "peace", "phone", "piece", "place", "plant", "point",
            "power", "price", "prove", "quite", "radio", "raise", "range", "reach", "ready", "right", "scene", "score",
            "sense", "serve", "seven", "shake", "share", "shoot", "short", "since", "skill", "small", "smile", "sound",
            "south", "space", "speak", "spend", "sport", "staff", "stage", "stand", "start", "state", "still", "stock",
            "store", "story", "study", "stuff", "style", "table", "teach", "thank", "their", "there", "these", "thing",
            "think", "third", "those", "three", "throw", "today", "total", "tough", "trade", "treat", "trial", "truth",
            "under", "until", "value", "visit", "voice", "watch", "water", "where", "which", "while", "white", "whole",
            "whose", "woman", "world", "worry", "would", "write", "wrong", "young"],
        6: ["accept", "across", "action", "affect", "agency", "almost", "always", "amount", "animal", "answer",
            "anyone", "appear", "around", "arrive", "artist", "assume", "attack", "author", "become", "before",
            "behind", "better", "beyond", "budget", "camera", "cancer", "career", "center", "chance", "change",
            "charge", "choice", "choose", "church", "common", "couple", "course", "create", "debate", "decade",
            "decide", "degree", "design", "detail", "dinner", "doctor", "during", "effect", "effort", "either",
            "energy", "enough", "entire", "expect", "expert", "factor", "family", "father", "figure", "finger",
            "finish", "follow", "forget", "former", "friend", "future", "garden", "ground", "growth", "happen",
            "health", "impact", "indeed", "inside", "itself", "lawyer", "leader", "letter", "likely", "listen",
            "little", "manage", "market", "matter", "member", "memory", "method", "middle", "minute", "modern",
            "moment", "mother", "myself", "nation", "nature", "nearly", "notice", "number", "office", "option",
            "others", "parent", "people", "period", "person", "player", "police", "policy", "pretty", "public",
            "rather", "really", "reason", "recent", "record", "reduce", "region", "relate", "remain", "remove",
            "report", "result", "return", "reveal", "school", "season", "second", "senior", "series", "sexual",
            "should", "simple", "simply", "single", "sister", "social", "source", "speech", "spring", "street",
            "strong", "suffer", "summer", "system", "theory", "though", "threat", "toward", "travel", "victim",
            "weapon", "weight", "window", "within", "wonder", "worker", "writer"],
        7: ["ability", "account", "address", "against", "already", "another", "article", "because", "believe",
            "benefit", "between", "billion", "brother", "capital", "central", "century", "certain", "citizen",
            "clearly", "college", "company", "compare", "concern", "contain", "control", "country", "culture",
            "current", "defense", "despite", "develop", "discuss", "disease", "economy", "evening", "exactly",
            "example", "explain", "federal", "feeling", "finally", "foreign", "forward", "general", "herself",
            "himself", "history", "however", "hundred", "husband", "imagine", "improve", "include", "instead",
            "involve", "kitchen", "machine", "manager", "measure", "medical", "meeting", "mention", "message",
            "million", "mission", "morning", "natural", "network", "nothing", "officer", "outside", "partner",
            "patient", "pattern", "perform", "perhaps", "picture", "popular", "prepare", "present", "prevent",
            "private", "problem", "process", "produce", "product", "program", "project", "protect", "provide",
            "purpose", "quality", "quickly", "reality", "realize", "receive", "reflect", "require", "respond",
            "science", "section", "serious", "service", "several", "similar", "society", "soldier", "someone",
            "special", "station", "student", "subject", "success", "suggest", "support", "surface", "teacher",
            "thought", "through", "tonight", "trouble", "usually", "various", "western", "whether", "without"],
        8: ["activity", "actually", "although", "American", "analysis", "anything", "approach", "attorney", "audience",
            "behavior", "building", "business", "campaign", "computer", "Congress", "consider", "consumer", "continue",
            "cultural", "customer", "daughter", "decision", "Democrat", "describe", "director", "discover", "economic",
            "election", "employee", "everyone", "evidence", "hospital", "identify", "increase", "indicate", "industry",
            "interest", "language", "magazine", "maintain", "majority", "marriage", "material", "military", "movement",
            "national", "official", "painting", "personal", "physical", "politics", "position", "positive", "possible",
            "practice", "pressure", "probably", "property", "question", "recently", "remember", "research", "resource",
            "response", "security", "shoulder", "somebody", "southern", "specific", "standard", "strategy", "suddenly",
            "thousand", "together", "training", "violence", "whatever", "yourself"],
        9: ["according", "agreement", "attention", "authority", "available", "beautiful", "candidate", "certainly",
            "challenge", "character", "community", "condition", "determine", "different", "difficult", "direction",
            "education", "establish", "everybody", "executive", "financial", "important", "including", "interview",
            "knowledge", "necessary", "newspaper", "operation", "political", "president", "professor", "recognize",
            "religious", "represent", "scientist", "situation", "something", "sometimes", "statement", "structure",
            "treatment"],
        10: ["collection", "commercial", "conference", "democratic", "difference", "discussion", "especially",
             "everything", "experience", "generation", "government", "individual", "investment", "management",
             "particular", "population", "production", "Republican", "successful", "technology", "television",
             "themselves", "throughout", "understand"],
        11: ["development", "environment", "information", "institution", "interesting", "opportunity", "participant",
             "performance", "significant", "traditional"],
        12: ["organization", "particularly", "professional", "relationship"],
        13: ["environmental", "international"],
        14: ["administration", "responsibility"]
    }
}
